@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,18 +23,25 @@ from .types.cloud_redis import ExportInstanceRequest
 from .types.cloud_redis import FailoverInstanceRequest
 from .types.cloud_redis import GcsDestination
 from .types.cloud_redis import GcsSource
+from .types.cloud_redis import GetInstanceAuthStringRequest
 from .types.cloud_redis import GetInstanceRequest
 from .types.cloud_redis import ImportInstanceRequest
 from .types.cloud_redis import InputConfig
 from .types.cloud_redis import Instance
+from .types.cloud_redis import InstanceAuthString
 from .types.cloud_redis import ListInstancesRequest
 from .types.cloud_redis import ListInstancesResponse
 from .types.cloud_redis import LocationMetadata
+from .types.cloud_redis import MaintenancePolicy
+from .types.cloud_redis import MaintenanceSchedule
 from .types.cloud_redis import NodeInfo
 from .types.cloud_redis import OperationMetadata
 from .types.cloud_redis import OutputConfig
+from .types.cloud_redis import RescheduleMaintenanceRequest
+from .types.cloud_redis import TlsCertificate
 from .types.cloud_redis import UpdateInstanceRequest
 from .types.cloud_redis import UpgradeInstanceRequest
+from .types.cloud_redis import WeeklyMaintenanceWindow
 from .types.cloud_redis import ZoneMetadata
 
 __all__ = (
@@ -46,17 +53,24 @@ __all__ = (
     "FailoverInstanceRequest",
     "GcsDestination",
     "GcsSource",
+    "GetInstanceAuthStringRequest",
     "GetInstanceRequest",
     "ImportInstanceRequest",
     "InputConfig",
     "Instance",
+    "InstanceAuthString",
     "ListInstancesRequest",
     "ListInstancesResponse",
     "LocationMetadata",
+    "MaintenancePolicy",
+    "MaintenanceSchedule",
     "NodeInfo",
     "OperationMetadata",
     "OutputConfig",
+    "RescheduleMaintenanceRequest",
+    "TlsCertificate",
     "UpdateInstanceRequest",
     "UpgradeInstanceRequest",
+    "WeeklyMaintenanceWindow",
     "ZoneMetadata",
 )
