@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -243,7 +243,7 @@ class CloudRedisAsyncClient:
         are aggregated.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import redis_v1
 
@@ -345,7 +345,7 @@ class CloudRedisAsyncClient:
     ) -> cloud_redis.Instance:
         r"""Gets the details of a specific Redis instance.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import redis_v1
 
@@ -384,7 +384,7 @@ class CloudRedisAsyncClient:
 
         Returns:
             google.cloud.redis_v1.types.Instance:
-                A Google Cloud Redis instance.
+                A Memorystore for Redis instance.
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -423,6 +423,99 @@ class CloudRedisAsyncClient:
         # Done; return the response.
         return response
 
+    async def get_instance_auth_string(
+        self,
+        request: Union[cloud_redis.GetInstanceAuthStringRequest, dict] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> cloud_redis.InstanceAuthString:
+        r"""Gets the AUTH string for a Redis instance. If AUTH is
+        not enabled for the instance the response will be empty.
+        This information is not included in the details returned
+        to GetInstance.
+
+
+        .. code-block:: python
+
+            from google.cloud import redis_v1
+
+            def sample_get_instance_auth_string():
+                # Create a client
+                client = redis_v1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                request = redis_v1.GetInstanceAuthStringRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_instance_auth_string(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.redis_v1.types.GetInstanceAuthStringRequest, dict]):
+                The request object. Request for
+                [GetInstanceAuthString][google.cloud.redis.v1.CloudRedis.GetInstanceAuthString].
+            name (:class:`str`):
+                Required. Redis instance resource name using the form:
+                ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
+                where ``location_id`` refers to a GCP region.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.redis_v1.types.InstanceAuthString:
+                Instance AUTH string details.
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = cloud_redis.GetInstanceAuthStringRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.get_instance_auth_string,
+            default_timeout=600.0,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
     async def create_instance(
         self,
         request: Union[cloud_redis.CreateInstanceRequest, dict] = None,
@@ -450,7 +543,7 @@ class CloudRedisAsyncClient:
         hours, so there is no need to call DeleteOperation.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import redis_v1
 
@@ -523,8 +616,8 @@ class CloudRedisAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.redis_v1.types.Instance` A Google
-                Cloud Redis instance.
+                :class:`google.cloud.redis_v1.types.Instance` A
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
@@ -594,7 +687,7 @@ class CloudRedisAsyncClient:
         there is no need to call DeleteOperation.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import redis_v1
 
@@ -659,8 +752,8 @@ class CloudRedisAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.redis_v1.types.Instance` A Google
-                Cloud Redis instance.
+                :class:`google.cloud.redis_v1.types.Instance` A
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
@@ -726,7 +819,7 @@ class CloudRedisAsyncClient:
         specified in the request.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import redis_v1
 
@@ -780,8 +873,8 @@ class CloudRedisAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.redis_v1.types.Instance` A Google
-                Cloud Redis instance.
+                :class:`google.cloud.redis_v1.types.Instance` A
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
@@ -852,7 +945,7 @@ class CloudRedisAsyncClient:
         few hours, so there is no need to call DeleteOperation.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import redis_v1
 
@@ -909,8 +1002,8 @@ class CloudRedisAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.redis_v1.types.Instance` A Google
-                Cloud Redis instance.
+                :class:`google.cloud.redis_v1.types.Instance` A
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
@@ -977,7 +1070,7 @@ class CloudRedisAsyncClient:
         few hours, so there is no need to call DeleteOperation.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import redis_v1
 
@@ -1034,8 +1127,8 @@ class CloudRedisAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.redis_v1.types.Instance` A Google
-                Cloud Redis instance.
+                :class:`google.cloud.redis_v1.types.Instance` A
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
@@ -1100,7 +1193,7 @@ class CloudRedisAsyncClient:
         Memorystore for Redis instance.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import redis_v1
 
@@ -1154,8 +1247,8 @@ class CloudRedisAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.redis_v1.types.Instance` A Google
-                Cloud Redis instance.
+                :class:`google.cloud.redis_v1.types.Instance` A
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
@@ -1218,7 +1311,7 @@ class CloudRedisAsyncClient:
         serving and data is deleted.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import redis_v1
 
@@ -1323,6 +1416,136 @@ class CloudRedisAsyncClient:
         # Done; return the response.
         return response
 
+    async def reschedule_maintenance(
+        self,
+        request: Union[cloud_redis.RescheduleMaintenanceRequest, dict] = None,
+        *,
+        name: str = None,
+        reschedule_type: cloud_redis.RescheduleMaintenanceRequest.RescheduleType = None,
+        schedule_time: timestamp_pb2.Timestamp = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Reschedule maintenance for a given instance in a
+        given project and location.
+
+
+        .. code-block:: python
+
+            from google.cloud import redis_v1
+
+            def sample_reschedule_maintenance():
+                # Create a client
+                client = redis_v1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                request = redis_v1.RescheduleMaintenanceRequest(
+                    name="name_value",
+                    reschedule_type="SPECIFIC_TIME",
+                )
+
+                # Make the request
+                operation = client.reschedule_maintenance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.redis_v1.types.RescheduleMaintenanceRequest, dict]):
+                The request object. Request for
+                [RescheduleMaintenance][google.cloud.redis.v1.CloudRedis.RescheduleMaintenance].
+            name (:class:`str`):
+                Required. Redis instance resource name using the form:
+                ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
+                where ``location_id`` refers to a GCP region.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            reschedule_type (:class:`google.cloud.redis_v1.types.RescheduleMaintenanceRequest.RescheduleType`):
+                Required. If reschedule type is SPECIFIC_TIME, must set
+                up schedule_time as well.
+
+                This corresponds to the ``reschedule_type`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            schedule_time (:class:`google.protobuf.timestamp_pb2.Timestamp`):
+                Optional. Timestamp when the maintenance shall be
+                rescheduled to if reschedule_type=SPECIFIC_TIME, in RFC
+                3339 format, for example ``2012-11-15T16:19:00.094Z``.
+
+                This corresponds to the ``schedule_time`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be
+                :class:`google.cloud.redis_v1.types.Instance` A
+                Memorystore for Redis instance.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name, reschedule_type, schedule_time])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = cloud_redis.RescheduleMaintenanceRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+        if reschedule_type is not None:
+            request.reschedule_type = reschedule_type
+        if schedule_time is not None:
+            request.schedule_time = schedule_time
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.reschedule_maintenance,
+            default_timeout=600.0,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            cloud_redis.Instance,
+            metadata_type=cloud_redis.OperationMetadata,
+        )
+
+        # Done; return the response.
+        return response
+
     async def __aenter__(self):
         return self
 
