@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -126,6 +126,11 @@ class CloudRedisTransport(abc.ABC):
             self.get_instance: gapic_v1.method.wrap_method(
                 self.get_instance, default_timeout=600.0, client_info=client_info,
             ),
+            self.get_instance_auth_string: gapic_v1.method.wrap_method(
+                self.get_instance_auth_string,
+                default_timeout=600.0,
+                client_info=client_info,
+            ),
             self.create_instance: gapic_v1.method.wrap_method(
                 self.create_instance, default_timeout=600.0, client_info=client_info,
             ),
@@ -147,6 +152,11 @@ class CloudRedisTransport(abc.ABC):
             self.delete_instance: gapic_v1.method.wrap_method(
                 self.delete_instance, default_timeout=600.0, client_info=client_info,
             ),
+            self.reschedule_maintenance: gapic_v1.method.wrap_method(
+                self.reschedule_maintenance,
+                default_timeout=600.0,
+                client_info=client_info,
+            ),
         }
 
     def close(self):
@@ -184,6 +194,17 @@ class CloudRedisTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def get_instance_auth_string(
+        self,
+    ) -> Callable[
+        [cloud_redis.GetInstanceAuthStringRequest],
+        Union[
+            cloud_redis.InstanceAuthString, Awaitable[cloud_redis.InstanceAuthString]
+        ],
+    ]:
+        raise NotImplementedError()
+
     @property
     def create_instance(
         self,
@@ -247,5 +268,14 @@ class CloudRedisTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def reschedule_maintenance(
+        self,
+    ) -> Callable[
+        [cloud_redis.RescheduleMaintenanceRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
 
 __all__ = ("CloudRedisTransport",)
