@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -328,6 +328,37 @@ class CloudRedisGrpcTransport(CloudRedisTransport):
             )
         return self._stubs["get_instance"]
 
+    @property
+    def get_instance_auth_string(
+        self,
+    ) -> Callable[
+        [cloud_redis.GetInstanceAuthStringRequest], cloud_redis.InstanceAuthString
+    ]:
+        r"""Return a callable for the get instance auth string method over gRPC.
+
+        Gets the AUTH string for a Redis instance. If AUTH is
+        not enabled for the instance the response will be empty.
+        This information is not included in the details returned
+        to GetInstance.
+
+        Returns:
+            Callable[[~.GetInstanceAuthStringRequest],
+                    ~.InstanceAuthString]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_instance_auth_string" not in self._stubs:
+            self._stubs["get_instance_auth_string"] = self.grpc_channel.unary_unary(
+                "/google.cloud.redis.v1.CloudRedis/GetInstanceAuthString",
+                request_serializer=cloud_redis.GetInstanceAuthStringRequest.serialize,
+                response_deserializer=cloud_redis.InstanceAuthString.deserialize,
+            )
+        return self._stubs["get_instance_auth_string"]
+
     @property
     def create_instance(
         self,
@@ -544,6 +575,33 @@ class CloudRedisGrpcTransport(CloudRedisTransport):
             )
         return self._stubs["delete_instance"]
 
+    @property
+    def reschedule_maintenance(
+        self,
+    ) -> Callable[[cloud_redis.RescheduleMaintenanceRequest], operations_pb2.Operation]:
+        r"""Return a callable for the reschedule maintenance method over gRPC.
+
+        Reschedule maintenance for a given instance in a
+        given project and location.
+
+        Returns:
+            Callable[[~.RescheduleMaintenanceRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "reschedule_maintenance" not in self._stubs:
+            self._stubs["reschedule_maintenance"] = self.grpc_channel.unary_unary(
+                "/google.cloud.redis.v1.CloudRedis/RescheduleMaintenance",
+                request_serializer=cloud_redis.RescheduleMaintenanceRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["reschedule_maintenance"]
+
     def close(self):
         self.grpc_channel.close()
 
